@@ -20,7 +20,7 @@
 */
 
 #include <config.h>
-#include <gtk/gtk.h>
+#include <gtk/gtkmain.h>
 #include "gtkhtml.h"
 #include "gtkhtml-private.h"
 #include "htmlcursor.h"
@@ -33,6 +33,8 @@
 #include "htmltable.h"
 #include "htmlembedded.h"
 
+#define BLINK_TIMEOUT 500
+
 static GdkColor table_stipple_active_on      = { 0, 0,      0,      0xffff };
 static GdkColor table_stipple_active_off     = { 0, 0xffff, 0xffff, 0xffff };
 static GdkColor table_stipple_non_active_on  = { 0, 0xaaaa, 0xaaaa, 0xaaaa };
@@ -46,14 +48,6 @@ static GdkColor cell_stipple_non_active_off = { 0, 0xffff, 0xffff, 0xffff };
 static GdkColor image_stipple_active_on      = { 0, 0xffff, 0,      0 };
 static GdkColor image_stipple_active_off     = { 0, 0xffff, 0xffff, 0xffff };
 
-static gint blink_timeout = 500;
-
-void
-html_engine_set_cursor_blink_timeout (gint timeout)
-{
-	blink_timeout = timeout;
-}
-
 void
 html_engine_hide_cursor  (HTMLEngine *engine)
 {
@@ -68,7 +62,7 @@ html_engine_hide_cursor  (HTMLEngine *engine)
 			if (e) {
 				e->caret_mode = engine->caret_mode;
 				html_cursor_copy(e->cursor, engine->cursor);
-			} else	e = engine;
+			} else 	e = engine;
 		}
 		html_engine_draw_cursor_in_area (e, 0, 0, -1, -1);
 	}
@@ -121,9 +115,9 @@ draw_cursor_rectangle (HTMLEngine *e, gint x1, gint y1, gint x2, gint y2,
 {
 	GdkGC *gc;
 	GdkColor color;
-	gint8 dashes[2] = { 1, 3 };
+	gint8 dashes [2] = { 1, 3 };
 
-	if (x1 > x2 || y1 > y2 || !e->window)
+	if (x1 > x2 || y1 > y2)
 		return;
 
 	gc = gdk_gc_new (e->window);
@@ -266,7 +260,7 @@ html_engine_draw_table_cursor (HTMLEngine *e)
 
 		html_object_calc_abs_position (to, &cr->x1, &cr->y2);
 		cr->x2 = cr->x1 + to->width - 1;
-		cr->y2--;
+		cr->y2 --;
 		cr->y1 = cr->y2 - (to->ascent + to->descent - 1);
 
 		animate = HTML_IS_TABLE (e->cursor->object) && !html_engine_get_table_cell (e);
@@ -303,7 +297,7 @@ html_engine_draw_cursor_in_area (HTMLEngine *engine,
 		return;
 
 	obj = engine->cursor->object;
-	if (obj == NULL || engine->window == NULL)
+	if (obj == NULL)
 		return;
 
 	offset = engine->cursor->offset;
@@ -315,6 +309,7 @@ html_engine_draw_cursor_in_area (HTMLEngine *engine,
 		y = 0;
 	}
 
+
 	html_object_get_cursor (obj, engine->painter, offset, &x1, &y1, &x2, &y2);
 	while (obj) {
 		if (html_object_is_frame(obj)) {
@@ -356,7 +351,7 @@ blink_timeout_cb (gpointer data)
 	g_return_val_if_fail (HTML_IS_ENGINE (data), FALSE);
 	engine = HTML_ENGINE (data);
 
-	engine->blinking_status = !engine->blinking_status;
+	engine->blinking_status = ! engine->blinking_status;
 
 	if (engine->blinking_status)
 		html_engine_show_cursor (engine);
@@ -377,10 +372,7 @@ html_engine_setup_blinking_cursor (HTMLEngine *engine)
 	engine->blinking_status = FALSE;
 
 	blink_timeout_cb (engine);
-	if (blink_timeout > 0)
-		engine->blinking_timer_id = g_timeout_add (blink_timeout, blink_timeout_cb, engine);
-	else
-		engine->blinking_timer_id = -1;
+	engine->blinking_timer_id = g_timeout_add (BLINK_TIMEOUT, blink_timeout_cb, engine);
 }
 
 void
@@ -395,8 +387,7 @@ html_engine_stop_blinking_cursor (HTMLEngine *engine)
 		engine->blinking_status = FALSE;
 	}
 
-	if (engine->blinking_timer_id != -1)
-		g_source_remove (engine->blinking_timer_id);
+	g_source_remove (engine->blinking_timer_id);
 	engine->blinking_timer_id = 0;
 }
 
@@ -412,16 +403,6 @@ html_engine_reset_blinking_cursor (HTMLEngine *engine)
 
 	html_engine_show_cursor (engine);
 	engine->blinking_status = TRUE;
-
-	if (engine->blinking_timer_id != -1)
-		g_source_remove (engine->blinking_timer_id);
-
-	if (blink_timeout > 0)
-		engine->blinking_timer_id = g_timeout_add (blink_timeout, blink_timeout_cb, engine);
-	else {
-		engine->blinking_timer_id = -1;
-		/* show the cursor */
-		engine->blinking_status = FALSE;
-		blink_timeout_cb (engine);
-	}
+	g_source_remove (engine->blinking_timer_id);
+	engine->blinking_timer_id = g_timeout_add (BLINK_TIMEOUT, blink_timeout_cb, engine);
 }
